module ast.Stmt;

import ast.Exp,
       ast.Decl;

import sema.SymbolTable;

enum StmtType
{
    Stmt,
    Decl,
    Exp,
    Return,
    If,
}

class Stmt
{
    this(StmtType stmtType = StmtType.Stmt)
    {
        this.stmtType = stmtType;
    }

    StmtType stmtType;
    Scope env;
}

class ReturnStmt : Stmt
{
    this()
    {
        super(StmtType.Return);
    }

    public Exp exp;
}

class DeclStmt : Stmt
{
    this(Decl decl)
    {
        super(StmtType.Decl);
        this.decl = decl;
    }

    public Decl decl;
}

class ExpStmt : Stmt
{
    this(Exp exp)
    {
        super(StmtType.Exp);
        this.exp = exp;
    }

    public Exp exp;
}

class IfStmt : Stmt
{
    this(Exp cond, Stmt[] then)
    {
        super(StmtType.If);
        this.cond = cond;
        this.then = then;
    }

    Exp cond;
    Stmt[] then;
}

